%% This script is testing the functionalities of the Dipolar Gas Simulator
%
%  Important:  Run only sectionwise!! 

%% - Create Simulator, Potential and Calculator object with specified options

OptionsStruct = struct;

OptionsStruct.NumberOfAtoms           = 1E6;
OptionsStruct.DipolarPolarAngle       = pi/2;
OptionsStruct.DipolarAzimuthAngle     = 0;
OptionsStruct.ScatteringLength        = 86;
OptionsStruct.TrapFrequencies         = [125, 125, 250];
OptionsStruct.NumberOfGridPoints      = [64, 64, 48];
OptionsStruct.Dimensions              = [40, 40, 20];
OptionsStruct.CutoffType              = 'Cylindrical';
OptionsStruct.TrapPotentialType       = 'Harmonic';

OptionsStruct.SimulationMode          = 'ImaginaryTimeEvolution'; % 'ImaginaryTimeEvolution' | 'RealTimeEvolution'
OptionsStruct.TimeStep                = 50e-06; % in s
OptionsStruct.SimulationTime          =  4e-03; % in s

OptionsStruct.SaveData                = true;
OptionsStruct.SaveDirectory           = './Data';

options                               = Helper.convertstruct2cell(OptionsStruct);
clear OptionsStruct

sim  = Simulator.DipolarGas(options{:});
calc = Simulator.Calculator(options{:});
pot  = Simulator.Potentials(options{:});

%-% Run Simulation %-%
[Params, Transf, psi, V, VDk] = sim.runSimulation(calc);

%% - Plot numerical grid
Plotter.visualizeSpace(Transf)
%% - Plot trap potential
Plotter.visualizeTrapPotential(V,Params,Transf)
%% - Plot initial wavefunction
Plotter.visualizeWavefunction(psi,Params,Transf)